- labs
A character vector of ID labels.
- sex
A vector of the same length as labs, with entries 1 (male) or 2
(female).
- extra
Either the word "parents" (default), or a non-negative integer.
See Details.
- age
A numeric or character vector. If numeric, and age[i] < age[j],
then individual i will not be an ancestor of individual j. The numbers
themselves are irrelevant, only the partial ordering. (No inference is made
about individuals of equal age.) Alternatively, for finer control, age
may be a character vector of inequalities, e.g., age = c("1>2", "1>3").
- knownPO
A list of vectors of length 2, containing the ID labels of
pairs known to be parent-offspring. By default, both directions are
considered; use age to force a specific direction.
- knownSub
A ped object involving a subset of the labs individuals.
- allKnown
A logical. If TRUE, no other pairs than knownPO will be
assigned as parent-offspring. If FALSE (default), all pairs except those in
notPO are treated as potential parent-offspring.
- notPO
A list of vectors of length 2, containing the ID labels of pairs
known not to be parent-offspring.
- noChildren
A vector of ID labels, indicating individuals without
children of their own.
- connected
A logical. If TRUE (default), only connected pedigrees are
returned.
- maxInbreeding
A single numeric indicating the highest permitted
inbreeding coefficient. Default: 1/16 (as with first-cousin parents.)
- linearInb
A parameter controlling the maximum separation of linearly
related spouses. Either TRUE (allow all linear inbreeding), FALSE (disallow
all) or a non-negative integer. For example, linearInb = 1 allows
parent/child mating, but not grandparent/grandchild or more distant linear
relatives. Default: FALSE.
- sexSymmetry
A logical. If TRUE (default), pedigrees which are equal
except for the gender distribution of the added parents, are regarded as
equivalent, and only one of each equivalence class is returned. Example:
paternal vs. maternal half sibs.
- verbose
A logical.